## 7.0.5 (2022-03-09)

Remove Python 2 support from some third-party distributions (#7466)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 7.0.4 (2022-01-31)

Upgrade black version (#7089)

## 7.0.3 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 7.0.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 7.0.0 (2021-09-19)

Update third-party package versions (#5996)

